Skip to contents

Displays password retrieval tokens for users and allows admins to add new users, download user annotations, and reset user annotations.

Usage

adminUI(id, cfg)

Arguments

id

Module namespace

cfg

App configuration object

Value

A Shiny UI element