Skip to contents

Provides the user interface for logging in to the B1MG Variant Voting application. This module is based on shinyauthr and includes reactive user authentication.

Usage

loginUI(id, cfg)

Arguments

id

A string identifier for the module namespace.

Value

A Shiny UI element (typically a login panel) rendered within a namespace.