Login module UI
loginUI.RdProvides the user interface for logging in to the B1MG Variant Voting application.
This module is based on shinyauthr and includes reactive user authentication.
loginUI.RdProvides the user interface for logging in to the B1MG Variant Voting application.
This module is based on shinyauthr and includes reactive user authentication.